/*
 * Copyright (C) 2015 Weng Xuetian <wengxt@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#ifndef WACOMTABLETSERVICE_H
#define WACOMTABLETSERVICE_H

#include <QtGlobal>

#include <Plasma5Support/Service>
namespace Plasma = Plasma5Support;

class WacomTabletService : public Plasma::Service
{
    Q_OBJECT
public:
    WacomTabletService(const QString &destination,
                       QObject *parent = nullptr);
    ~WacomTabletService() override;

protected:
    Plasma::ServiceJob *createJob(const QString &operation,
                                  QMap<QString, QVariant> &parameters) Q_DECL_OVERRIDE;
};

#endif // WACOMTABLETSERVICE_H
